@@ -10,4 +10,10 @@
 #' @importFrom Rcpp sourceCpp
 #' @docType package
 #' @aliases urltools urltools-package
-NULL
\ No newline at end of file
+NULL
+
+#'@rdname param_get
+#'@export
+url_parameters <- function(urls, parameter_names){
+  return(param_get(urls, parameter_names))
+}
\ No newline at end of file
